@@ -9,7 +9,7 @@ from __future__ import unicode_literals
 __author__ = 'Florian Rhiem (florian.rhiem@gmail.com)'
 __copyright__ = 'Copyright (c) 2013 Florian Rhiem'
 __license__ = 'MIT'
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 
 import ctypes
 import os
@@ -127,7 +127,7 @@ def _glfw_get_version(filename):
     args = [sys.executable, '-c', textwrap.dedent(version_checker_source)]
     process = subprocess.Popen(args, universal_newlines=True,
                                stdin=subprocess.PIPE, stdout=subprocess.PIPE)
-    out = process.communicate(_to_char_p(filename))[0]
+    out = process.communicate(filename)[0]
     out = out.strip()
     if out:
         return eval(out)
@@ -135,7 +135,8 @@ def _glfw_get_version(filename):
         return None
 
 _glfw = _load_library(['glfw', 'glfw3'], ['.so', '.dylib', '.dll'],
-                      ['', '/usr/lib', '/usr/local/lib'], _glfw_get_version)
+                      ['', '/usr/lib', '/usr/local/lib', 
+                       '/usr/lib/x86_64-linux-gnu/'], _glfw_get_version)
 if _glfw is None:
     raise ImportError("Failed to load GLFW3 shared library.")
 
@@ -806,7 +807,8 @@ def destroy_window(window):
     window_addr = ctypes.cast(ctypes.pointer(window),
                               ctypes.POINTER(ctypes.c_ulong)).contents.value
     for callback_repository in _callback_repositories:
-        del callback_repository[window_addr]
+        if window_addr in callback_repository:
+            del callback_repository[window_addr]
 
 _glfw.glfwWindowShouldClose.restype = ctypes.c_int
 _glfw.glfwWindowShouldClose.argtypes = [ctypes.POINTER(_GLFWwindow)]
